@@ -1,6 +1,6 @@
 from __future__ import absolute_import, print_function
 
-from flow_network.flow_network import FlowNetwork, MinimumCostFlow
+from flow_network.flow_network import MaximumFlow, MinimumCostFlow
 
 from .__version__ import __title__, __description__, __url__
 from .__version__ import __version__, __build__, __author__
