@@ -1,7 +1,7 @@
 __title__ = 'flow-network'
-__description__ = 'Flow Network C++ Implementation'
+__description__ = 'Flow Network Python Library'
 __url__ = 'https://github.com/LucienShui/flow-network'
-__version_info__ = (0, 1, 8)
+__version_info__ = (0, 1, 9)
 __version__ = '.'.join(map(str, __version_info__))
 __build__ = eval(f"0x{''.join(map(lambda x: f'{int(x):02d}', __version_info__))}")
 __author__ = 'Lucien Shui'
