@@ -1,2 +1,2 @@
-from .maximum_flow import FlowNetwork
+from .maximum_flow import MaximumFlow
 from .minimum_cost_flow import MinimumCostFlow
